#! /usr/bin/env python
# -*- coding: utf-8 -*_
# Author: Liu Yang <mkliuyang@gmail.com>

from distutils.core import setup

setup(
    name='tagine',
    version='0.0.2',
    description='Sequence tagging interface library',
    author='Liu Yang',
    author_email='mkliuyang@gmail.com',
    url='https://gitlab.yunfutech.com/nlp_projects/Tagine',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)
